@@ -63,7 +63,6 @@ TextProcessor::TextProcessor(QWidget *parent) :
     connect(m_recipient->m_btSend,SIGNAL(clicked()),this,SLOT(sendSms()));
 
     m_smsEdit = ui->textEdit;
-    m_smsEdit->setReadOnly(true);
     m_phoneNumber = m_recipient->getPhoneNumberField();
 
     //Enabling scrolling
@@ -785,6 +784,7 @@ void TextProcessor::commit()
 {
     parentWidget()->parentWidget()->hide();
 
+    //wait a moment before commit, so client re-gain focus
     sleep(0.1);
 
     QDBusMessage msg = QDBusMessage::createMethodCall(
